@@ -1,6 +1,6 @@
 /*
     KMetronome - ALSA Sequencer based MIDI metronome
-    Copyright (C) 2006-2014, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2020, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -12,9 +12,8 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    You should have received a copy of the GNU General Public License
+    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef DRUMGRID_H
@@ -25,7 +24,6 @@
 #include <QMenu>
 #include <QShortcut>
 #include <QCloseEvent>
-#include <QSignalMapper>
 #include <QWidget>
 
 namespace Ui
@@ -33,24 +31,14 @@ namespace Ui
     class DrumGrid;
 }
 
-namespace drumstick
-{
-    class MidiClient;
-    class MidiPort;
-    class MidiQueue;
-    class SequencerEvent;
-}
-
 class SequencerAdapter;
 class DrumGridModel;
 
-using namespace drumstick;
-
 class DrumGrid : public QDialog
 {
     Q_OBJECT
 public:
-    DrumGrid(QWidget *parent = 0);
+    DrumGrid(QWidget *parent = nullptr);
     virtual ~DrumGrid();
     void setSequencer(SequencerAdapter* seq);
     void setModel(DrumGridModel* model);
@@ -64,8 +52,8 @@ public:
     void writePattern(const QString& name);
     void removePattern(const QString& name);
     void updateTempo(int newTempo);
-    void showEvent(QShowEvent* event);
-    void done(int r);
+    void showEvent(QShowEvent* event) override;
+    void done(int r) override;
     QStringList patterns();
     QString currentPattern() { return m_currentPattern; }
     void setFigure(int figure);
@@ -101,7 +89,6 @@ private:
     int m_figure;
     int m_columns;
     unsigned long m_tick;
-    QSignalMapper* m_mapper;
     QVector<QShortcut*> m_shortcuts;
     QString m_currentPattern;
     QMenu* m_popup;
