@@ -1,9 +1,9 @@
 /*
   KMetronome - ALSA Sequencer based MIDI metronome
-  Copyright (C) 2005-2014 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+  Copyright (C) 2005-2020 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
   For this file, the following copyright notice is also applicable:
-  Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+  Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
   See http://qtractor.sourceforge.net
 
   This program is free software; you can redistribute it and/or modify
@@ -17,9 +17,7 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-  MA 02110-1301, USA
+  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
 /*  Library of compatible instrument definitions:
