@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2014 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2020 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,10 +12,8 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            *
- *   MA 02110-1301, USA                                                    *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
  ***************************************************************************/
 
 #ifndef KMETRONOME_H
@@ -39,7 +37,7 @@ class KMetronome : public QMainWindow
     Q_CLASSINFO("D-Bus Interface", "net.sourceforge.kmetronome")
 
 public:
-    KMetronome(QWidget* parent=0);
+    KMetronome(QWidget* parent = nullptr);
     virtual ~KMetronome();
 
     void display(int, int);
@@ -57,8 +55,8 @@ public:
     void retranslateUi();
 
 protected:
-    void closeEvent(QCloseEvent *event);
-    void mouseDoubleClickEvent ( QMouseEvent * e );
+    void closeEvent(QCloseEvent *event) override;
+    void mouseDoubleClickEvent ( QMouseEvent * e ) override;
 
 public Q_SLOTS:
     void about();
@@ -91,8 +89,8 @@ protected Q_SLOTS:
     void editPatterns();
     void patternChanged(int);
     void updatePatterns();
-    void exportPatterns();
-    void importPatterns();
+    void slotExportPatterns();
+    void slotImportPatterns();
     void slotSwitchLanguage(QAction *action);
 
 private:
