@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2014 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2020 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,13 +12,12 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            *
- *   MA 02110-1301, USA                                                    *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
  ***************************************************************************/
 
 #include "kmetropreferences.h"
+#include "iconutils.h"
 
 KMetroPreferences::KMetroPreferences(QWidget *parent)
     : QDialog(parent)
@@ -31,6 +30,7 @@ KMetroPreferences::KMetroPreferences(QWidget *parent)
              SLOT(slotBankChanged(int)));
     connect( m_ui.m_program, SIGNAL(currentIndexChanged(int)),
              SLOT(slotProgramChanged(int)));
+    IconUtils::SetWindowIcon(this);
 }
 
 KMetroPreferences::~KMetroPreferences()
