@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2014 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2020 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,10 +12,8 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
  *   GNU General Public License for more details.                          *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            *
- *   MA 02110-1301, USA                                                    *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program. If not, see <http://www.gnu.org/licenses/>.*
  ***************************************************************************/
 
 #include "sequenceradapter.h"
@@ -25,12 +23,14 @@
 #include <drumstick/alsaevent.h>
 #include <QStringList>
 
+using namespace drumstick::ALSA;
+
 SequencerAdapter::SequencerAdapter(QObject *parent) :
     QObject(parent),
-    m_Client(0),
-    m_Port(0),
-    m_Queue(0),
-    m_model(0),
+    m_Client(nullptr),
+    m_Port(nullptr),
+    m_Queue(nullptr),
+    m_model(nullptr),
     m_clientId(-1),
     m_inputPortId(-1),
     m_outputPortId(-1),
@@ -328,7 +328,7 @@ void SequencerAdapter::parse_sysex(SequencerEvent *ev)
 {
 	int num, den;
 	SysExEvent* syx = static_cast<SysExEvent*>(ev);
-	if (syx == NULL)
+	if (syx == nullptr)
 	    return;
 	unsigned char *ptr =(unsigned char *) syx->getData();
 	if (syx->getLength() < 6) return;
